# Kismet
A dice roll parser with an optional personality module.
Comes with a Jupyter kernel.

## Installation
### pip
```bash
pip install kismet
```

### Jupyter
After installation with `pip`, you may optionally install the Jupyter kernel:
```bash
pythom -m kismet.kernel.install
```
